/*
** Class:  LotROLinux.ImportWindow
** Author: Alan Jackson
** Date:   10th January 2008
**
** Window to import settings from previous version
** of the LotROLinux launcher
** for the game Lord of the Rings Online
**
** Based on a script by SNy <SNy@bmx-chemnitz.de>
**
** (C) 2007-2008 AJackson <ajackson@bcs.org.uk>
**
** This file is part of LotROLinux.
**
** LotROLinux is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**
** LotROLinux is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with LotROLinux.  If not, see <http://www.gnu.org/licenses/>.
*/
using System;
using Glade;
using Gtk;

namespace LotROLinux
{
	public class ImportWindow
	{
		[Widget]
		private Dialog winImport;

		[Widget]
        private Label lblConvText;
        
		[Widget]
        private Button btnConvert;

		[Widget]
        private FileChooserButton fcbConfigFile;

		private const string txtNotFound = "\nNo configuration data found for the game\n\n";
		private const string txtImport = "\n\nSelect configuration file to import\n";
		private const string txtCreate = "or click new to manually enter details\n";
		private const string txtDDO = "Dungeons & Dragons Online";
		private const string txtLOTRO = "Lord of the Rings Online";
		private const string txtTest = " (Test)";

		public ImportWindow(bool usingDND, bool usingTest, string valHomeDir)
		{
			Glade.XML gxml = new Glade.XML (null, "ImportWindow.glade", "winImport", null);
			gxml.Autoconnect (this);

			if (usingTest)
			{
				if (usingDND)
				{
					lblConvText.Text = String.Format("{0}{1}{2}{3}{4}",
						txtNotFound, txtDDO, txtTest, txtImport, txtCreate);
				} else {
					lblConvText.Text = String.Format("{0}{1}{2}{3}{4}",
						txtNotFound, txtLOTRO, txtTest, txtImport, txtCreate);
				}
			} else {
				if (usingDND)
				{
					lblConvText.Text = String.Format("{0}{1}{2}{3}",
						txtNotFound, txtDDO, txtImport, txtCreate);
				} else {
					lblConvText.Text = String.Format("{0}{1}{2}{3}",
						txtNotFound, txtLOTRO, txtImport, txtCreate);
				}
			}

			fcbConfigFile.SetCurrentFolder(valHomeDir);
		}

		public ResponseType Run()
		{
			return (ResponseType)winImport.Run();
		}

		public void Destroy()
		{
			winImport.Destroy();
		}

		public string GetConfigFile()
		{
			return fcbConfigFile.Filename;
		}

		public string GetConfigFolder()
		{
			return fcbConfigFile.CurrentFolder;
		}

		protected virtual void OnFcbConfigFileSelectionChanged (object sender, System.EventArgs e)
		{
			if (fcbConfigFile.Filename != null)
			{
				btnConvert.Visible = true;
			}
		}
	}
}
