/*
** Class:  LotROLinux.MozillaStatus
** Author: Alan Jackson
** Date:   21st June 2007
**
** Class to determine if the mozilla library
** is accessible for the game Lord of the Rings Online
**
** Based on a script by SNy <SNy@bmx-chemnitz.de>
**
** (C) 2007-2008 AJackson <ajackson@bcs.org.uk>
**
** This file is part of LotROLinux.
**
** LotROLinux is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**
** LotROLinux is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with LotROLinux.  If not, see <http://www.gnu.org/licenses/>.
*/
using Gtk;
using System;
using System.IO;
using System.Net;
#if (GECKO)
using Gecko;
#endif

namespace LotROLinux
{
	public class MozillaStatus
	{
#if (GECKO)
		private WebControl htmlBrowser;
#else		
		private ScrolledWindow scrlBrowser;
		private Label htmlBrowser;
#endif

		public MozillaStatus()
		{
		}
		
		public Gtk.Widget GetBrowser()
		{
#if (GECKO)
			htmlBrowser = new WebControl();

			htmlBrowser.Visible = true;
			
			return htmlBrowser;
#else		
			scrlBrowser = new ScrolledWindow();

			htmlBrowser = new Label();

			scrlBrowser.AddWithViewport(htmlBrowser);
			scrlBrowser.Visible = true;
			htmlBrowser.Visible = true;
			htmlBrowser.SingleLineMode = false;
			htmlBrowser.WidthChars = 37;
			htmlBrowser.UseMarkup = true;
			htmlBrowser.Wrap = true;
			htmlBrowser.LineWrap = true;
			
			return scrlBrowser;
#endif
		}
		
		public void ShowUrl(string url)
		{
#if (GECKO)
			htmlBrowser.LoadUrl(url);
#else
			try
			{
				WebRequest web_request = WebRequest.Create (url);
				WebResponse web_response = web_request.GetResponse ();
				Stream stream = web_response.GetResponseStream ();
				StreamReader streamRead = new StreamReader(stream);

				htmlBrowser.Markup = "";

				string htmlBody = "";			
				string line;
				string newsTitle = "";
				string newsDate = "";
				bool inBody = false;

				while ((line = streamRead.ReadLine()) != null)
				{
					if (line.Length > 0)
					{
						if (inBody)
						{
							line = line.Replace("<br />", "\n");
							line = line.Replace("<br>", "\n");
							line = line.Replace("&nbsp;", " ");
							line = line.Replace("&Agrave;", "À");
							line = line.Replace("&agrave;", "à");
							line = line.Replace("&eacute;", "é");
							line = line.Replace("&Eacute;", "É");
							line = line.Replace("&ucirc;", "û");
							line = line.Replace("<p style=\"padding: 1px\">", "");
							line = line.Replace("<p>", "");
							line = line.Replace("</p>", "\n");
							line = line.Replace("</a>", "");
							line = line.Replace("</A>", "");
							line = line.Replace("</font>", "");
							line = line.Replace("</FONT>", "");
							line = line.Replace("<I>", "<i>");
							line = line.Replace("</I>", "</i>");
							line = line.Replace("<B>", "<b>");
							line = line.Replace("</B>", "</b>");
							line = line.Replace("<strong>", "<b>");
							line = line.Replace("</strong>", "</b>");
							line = line.Replace("<em>", "");
							line = line.Replace("</em>", "");
							line = line.Replace("&", "&amp;");

							while (line.ToUpper().Contains("HREF"))
							{
								int startPos = line.ToUpper().IndexOf("<A HREF");

								int endPos = -1;

								for(int loop = startPos; loop < line.Length ; loop++)
								{
									if (line.ToUpper().Substring(loop, 1) == ">")
									{
										endPos = loop + 1;
										break;
									}
								}

								line = line.Remove(startPos, endPos - startPos);
							}

							while (line.ToUpper().Contains("<FONT"))
							{
								int startPos = line.ToUpper().IndexOf("<FONT");

								int endPos = -1;

								for(int loop = startPos; loop < line.Length ; loop++)
								{
									if (line.ToUpper().Substring(loop, 1) == ">")
									{
										endPos = loop + 1;
										break;
									}
								}

								line = line.Remove(startPos, endPos - startPos);
							}

							if (line.ToUpper().Contains("</BODY>"))
							{
								inBody = false;
							} else if (line.ToUpper().Contains("LAUNCHERNEWSCHANNELCONTAINER"))
							{
								int startPos = line.ToUpper().IndexOf("CONTAINER\">") + 11;
								htmlBody += line.Substring(startPos);
							} else if (line.ToUpper().Contains("</DIV>") || 
								line.ToUpper().Contains("LAUNCHERNEWSITEMSCONTAINER"))
							{
								continue;
							} else if (line.ToUpper().Contains("LAUNCHERNEWSITEMCONTAINER")) {
								htmlBody += "\n";
							} else if (line.ToUpper().Contains("LAUNCHERNEWSITEMDATE")) {
								int startPos = line.ToUpper().IndexOf("DATE\">") + 6;
								newsDate = line.Substring(startPos);
							} else  if (line.ToUpper().Contains("LAUNCHERNEWSITEMTITLE")) {
								int startPos = line.ToUpper().IndexOf("TITLE\">") + 7;
								newsTitle = line.Substring(startPos);
							} else if (line.ToUpper().Contains("LAUNCHERNEWSITEMDESCRIPTION"))
							{
								if (newsTitle != "" && newsDate != "")
								{
									htmlBody += String.Format("\n{0} - {1}\n", newsDate, newsTitle);
								} else if (newsTitle != "") {
									htmlBody += String.Format("\n{0}\n", newsTitle);
								} else  if (newsDate != "") {
									htmlBody += String.Format("\n{0}\n", newsDate);
								}
								newsTitle = "";
								newsDate = "";

								int startPos = line.ToUpper().IndexOf("DESCRIPTION\">") + 13;
								htmlBody += String.Format("{0}", line.Substring(startPos));
							} else {
								htmlBody += String.Format("{0}", line);
							}
						} else {
							if (line.ToUpper().Contains("<BODY>"))
							{
								inBody = true;
							}
						}
					}
				}

				htmlBrowser.Markup = htmlBody;

				streamRead.Close();
				stream.Close();
			}
			catch
			{
				htmlBrowser.Markup = "<b>Error processing news</b>";
			}
#endif
		}
	}
}
